"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const ImTool_1 = require("./ImTool");
const waitForImageToLoad = (src, resolve, reject) => {
    let img = new Image();
    img.onload = () => {
        resolve(new ImTool_1.ImTool(img));
    };
    img.onerror = (err) => {
        // The image couldn't be loaded.
        reject(err);
    };
    img.src = src;
};
const fromMediaStream = (stream) => new Promise((resolve, reject) => __awaiter(void 0, void 0, void 0, function* () {
    const video = document.createElement('video');
    video.srcObject = stream;
    video.play();
    video.addEventListener('playing', () => {
        const tool = new ImTool_1.ImTool(video);
        video.srcObject = null;
        stream.getTracks().forEach((track) => track.stop());
        resolve(tool);
    });
    video.addEventListener('error', (e) => {
        reject(e);
    });
}));
/**
 * Creates a new instance of ImTool from an image URL, Blob, File or an image element.
 * The image be from the same origin, or from an origin accessible to the website.
 * @param image The image to be loaded.
 */
function fromImage(image) {
    if (typeof image === 'string') {
        return new Promise((resolve, reject) => {
            waitForImageToLoad(image, resolve, reject);
        });
    }
    else if (image instanceof Blob || image instanceof File) {
        return new Promise((resolve, reject) => {
            const reader = new FileReader();
            reader.addEventListener('load', () => {
                waitForImageToLoad(reader.result, resolve, reject);
            });
            reader.readAsDataURL(image);
        });
    }
    else if (image instanceof HTMLImageElement) {
        if (image.complete && image.naturalWidth === 0) {
            return Promise.resolve(new ImTool_1.ImTool(image));
        }
        else {
            return new Promise((resolve, reject) => {
                waitForImageToLoad(image.src, resolve, reject);
            });
        }
    }
    else {
        return Promise.reject(new Error('Unable to load the image.'));
    }
}
exports.fromImage = fromImage;
;
/**
 * Creates a new instance of ImTool from screen capture.
 */
function fromScreen() {
    return new Promise((resolve, reject) => __awaiter(this, void 0, void 0, function* () {
        var _a;
        // @ts-ignore TS's dom.lib.ts doesn't have support for this, yet.
        if (!((_a = navigator.mediaDevices) === null || _a === void 0 ? void 0 : _a.getDisplayMedia)) {
            reject(new Error('Screen capture is not supported.'));
        }
        // @ts-ignore TS's dom.lib.ts doesn't have support for this, yet.
        let stream = yield navigator.mediaDevices.getDisplayMedia({
            video: true
        });
        if (!stream) {
            reject(new Error('Unable to start screen capture.'));
        }
        resolve(fromMediaStream(stream));
    }));
}
exports.fromScreen = fromScreen;
;
/**
 * Creates a new instance of ImTool from webcam capture.
 */
function fromWebcam() {
    return new Promise((resolve, reject) => __awaiter(this, void 0, void 0, function* () {
        var _a;
        if (!((_a = navigator.mediaDevices) === null || _a === void 0 ? void 0 : _a.getUserMedia)) {
            reject(new Error('Webcam capture is not supported.'));
        }
        let stream = yield navigator.mediaDevices.getUserMedia({
            video: true
        });
        if (!stream) {
            reject(new Error('Unable to start webcam capture.'));
        }
        resolve(fromMediaStream(stream));
    }));
}
exports.fromWebcam = fromWebcam;
;
//# sourceMappingURL=index.js.map